"use strict";
// validates svgo opts
// to contain minimal set of plugins that will strip some stuff
// for the babylon JSX parser to work
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const lodash_isplainobject_1 = __importDefault(require("lodash.isplainobject"));
const lodash_clonedeep_1 = __importDefault(require("lodash.clonedeep"));
const essentialPlugins = {
    removeDoctype: true,
    removeComments: true,
    removeStyleElement: true
};
// If not explicitly set by the user, then set this value
const pluginDefaults = {
    removeViewBox: false
};
function getPlugin(pluginLike, value = true) {
    if (typeof pluginLike === "string") {
        return [
            pluginLike,
            {
                [pluginLike]: value
            }
        ];
    }
    const pluginName = Object.keys(pluginLike)[0];
    return [pluginName, pluginLike];
}
function validateAndFix(opts = {}) {
    if (!lodash_isplainobject_1.default(opts))
        throw new Error("Expected options.svgo to be Object.");
    let cleanOpts = lodash_clonedeep_1.default(opts);
    const plugins = new Map();
    // add user input plugins to the map
    if (Array.isArray(cleanOpts.plugins)) {
        for (const plugin of cleanOpts.plugins) {
            const p = getPlugin(plugin);
            plugins.set(p[0], p[1]);
        }
    }
    for (let plugin in essentialPlugins) {
        if (hop(essentialPlugins, plugin)) {
            const p = getPlugin(plugin, essentialPlugins[plugin]);
            // overwrite
            plugins.set(p[0], p[1]);
        }
    }
    for (let plugin in pluginDefaults) {
        if (hop(pluginDefaults, plugin)) {
            const p = getPlugin(plugin, pluginDefaults[plugin]);
            // do not overwrite
            const existingPlugin = plugins.get(p[0]);
            if (existingPlugin == null) {
                plugins.set(p[0], p[1]);
            }
        }
    }
    cleanOpts.plugins = [];
    for (const [, plugin] of plugins) {
        cleanOpts.plugins.push(plugin);
    }
    return cleanOpts;
}
exports.validateAndFix = validateAndFix;
function hop(o, key) {
    return Object.prototype.hasOwnProperty.call(o, key);
}
//# sourceMappingURL=svgo.js.map